/**
 * サンプルプログラム2_hash: 『<biz-stream_home>/sample/java/Sample2_hash.java』
 * プログラムで生成されたデータをデータソースとしてPDFを生成するサンプルです。
 *
 * @author Copyright 2001-2017 BrainSellers.com Corp. All Rights Reserved
 * @version 1.0.0
 * @since 5.0.0
 */

import java.io.FileNotFoundException;
import java.io.IOException;

import com.brainsellers.pdf.PDFRuntimeException;
import com.brainsellers.xml.JaxpXML;
import com.brainsellers.xml.common.XMLSuper;
import com.brainsellers.xml.datatypes.HashtableType;
import com.brainsellers.xml.datatypes.RecordType;

public class Sample2_hash {

	public static void main(String args[]) {
		new Sample2_hash(args);
		System.exit(0);
	}

	public Sample2_hash(String args[]) {
		try {
			// (1) 入出力共にファイル名で指定する
			XMLSuper xml = new JaxpXML(
					"${base-dir}/sample/java/Sample2_hash-doc.xml",
					"${base-dir}/sample/java/Sample2_hash.pdf");

			// (2) レイアウト情報(XML)の解析を行う
			xml.parse();

			// (3) 用紙サイズ、セキュリティ等の文書情報はドキュメントレイアウトで定義するので
			// アプリケーションでは設定しません。改ページ処理も必要ありません。

			// (4) ドキュメントレイアウトで指定されているデータソースに合わせてデータをセットし
			// PDFを出力する
			xml.setDataSource("app-resource", getRecord(0));

			// (5) 座標計算を行う
			xml.calcDataSize();

			// (6) PDFを生成する
			xml.toPDF(); //

			// (7) PDFを出力する
			xml.close();

		} catch (PDFRuntimeException e) {
			e.printStackTrace();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * ダミーのデータソースを生成する
	 *
	 * @param idx
	 *            添え字
	 * @return 配列のデータソース
	 */
	private RecordType getRecord(int idx) {
		RecordType rec = new RecordType();

		for (int i = 0; i < 30; i++) {
			HashtableType table = new HashtableType();
			table.put("Name", "Name" + idx + ":" + i);
			table.put("HeadOfState", "HeadOfState" + idx + ":" + i);
			table.put("GNP", String.valueOf(1000 * idx + i));
			rec.add(table);
		}

		return rec;
	}

}
